#!/bin/bash
set -e

{% set cluster_data = jsonMap(container.clusterData()) %}
{% set instance_data = jsonMap(container.instanceData()) %}

WHOAMI=$(whoami)
if [ $WHOAMI == "root" ]; then
    exec setuser founduser $0 $*
fi

cd /app

mkdir -p logs
BOOT_LOG_FILE=logs/boot.log
# save stdout and stderr for later
exec 3>&1 4>&2
exec >  >(ts '%Y-%m-%dT%H:%M:%S%z' |tee -a $BOOT_LOG_FILE)
exec 2> >(ts '%Y-%m-%dT%H:%M:%S%z' |tee -a $BOOT_LOG_FILE >&2)

echo "Booting at $(date)"

echo "Done preparing, starting Kibana. See Kibana logs for further output."

# used by the request-filter in kibana
export CLUSTER_NAME={{ container.id().group() }}
# used by the cloud headers patch in kibana
export ELASTICSEARCH_CLUSTER_NAME={{ cluster_data.elasticsearch_cluster_id }}

# used by metricbeat
export ECE_COMPONENT="kibana"
export ECE_CLUSTER_NAME="{{ container.id().group() }}"
export ECE_INSTANCE_ID="{{ container.id().name() }}"
export ECE_CLUSTER_VERSION="{{ container.versionString() }}"

exec 1>&3 2>&4

# TODO: add a marker for found-es-monitor to find? e.g -Dfound.kibana_cluster_name={{ container.id().group() }} -Dfound.kibana_instance_name={{ container.id().name() }}

{% if instance_data.instance_capacity > 128 %}
NODE_OPTIONS="--max-old-space-size=700" exec /kibana/bin/kibana -c /app/config/kibana.yml $*
{% else %}
exec /kibana/bin/kibana -c /app/config/kibana.yml $*
{% endif %}
